@@ -37,14 +37,6 @@ sub run {
     # Only for non-cdbs packages
     return if $info->relation('build-depends-all')->implies('cdbs');
 
-    # arch:any and debhelper version 9.20120312
-    if ( $info->field('architecture') ne 'all'
-        && !$info->relation('build-depends')
-        ->implies('debhelper (>= 9.20120312~)') )
-    {
-        tag 'arch-any-package-needs-newer-debhelper';
-    }
-
     # Module::Build::Tiny and debhelper version 9.20140227
     if ( $info->relation('build-depends-all')
         ->implies('libmodule-build-tiny-perl')
